Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClément Foucault <foucault.clem@gmail.com>2021-11-01 14:15:09 +0300
committerClément Foucault <foucault.clem@gmail.com>2021-11-01 14:15:09 +0300
commit3f0991266f418e1b256d8157f83fe2ba3c05014d (patch)
tree38c0c8d0cee18d0d8e7f297c6ce5cf4d210bec9e /intern/cycles/device/cuda
parenta96b2f39b82373d05f543bba325b2dd21baabf63 (diff)
parent81bd49d4fea41f6e569f3778724b33f15e95f853 (diff)
Merge branch 'blender-v3.0-release'
Diffstat (limited to 'intern/cycles/device/cuda')
-rw-r--r--intern/cycles/device/cuda/device_impl.cpp10
1 files changed, 7 insertions, 3 deletions
diff --git a/intern/cycles/device/cuda/device_impl.cpp b/intern/cycles/device/cuda/device_impl.cpp
index 2f9a1394ad8..2bb0592bcc5 100644
--- a/intern/cycles/device/cuda/device_impl.cpp
+++ b/intern/cycles/device/cuda/device_impl.cpp
@@ -378,7 +378,9 @@ string CUDADevice::compile_kernel(const uint kernel_features,
cubin.c_str(),
common_cflags.c_str());
- printf("Compiling CUDA kernel ...\n%s\n", command.c_str());
+ printf("Compiling %sCUDA kernel ...\n%s\n",
+ (use_adaptive_compilation()) ? "adaptive " : "",
+ command.c_str());
# ifdef _WIN32
command = "call " + command;
@@ -405,13 +407,15 @@ string CUDADevice::compile_kernel(const uint kernel_features,
bool CUDADevice::load_kernels(const uint kernel_features)
{
/* TODO(sergey): Support kernels re-load for CUDA devices.
*
* Currently re-loading kernel will invalidate memory pointers,
* causing problems in cuCtxSynchronize.
*/
if (cuModule) {
- VLOG(1) << "Skipping kernel reload, not currently supported.";
+ if (use_adaptive_compilation()) {
+ VLOG(1) << "Skipping CUDA kernel reload for adaptive compilation, not currently supported.";
+ }
return true;
}
@@ -405,13 +407,15 @@ string CUDADevice::compile_kernel(const uint kernel_features,
bool CUDADevice::load_kernels(const uint kernel_features)
{
- /* TODO(sergey): Support kernels re-load for CUDA devices.
+ /* TODO(sergey): Support kernels re-load for CUDA devices adaptive compile.
*
* Currently re-loading kernel will invalidate memory pointers,